diff --git a/dumux/boxmodels/MpNc/MpNcproperties.hh b/dumux/boxmodels/MpNc/MpNcproperties.hh
index 40edab43e95b44eb195e8f2fd6dfc4b3b7534b84..f8151fe7dfb80e32a5bb7440c4da9cf13ca6cdbf 100644
--- a/dumux/boxmodels/MpNc/MpNcproperties.hh
+++ b/dumux/boxmodels/MpNc/MpNcproperties.hh
@@ -49,7 +49,7 @@ NEW_PROP_TAG(MPNCVtkMassModule); //!< Vtk writer module for writing the mass rel
 NEW_PROP_TAG(MPNCVtkEnergyModule); //!< Vtk writer module for writing the energy related quantities into the VTK output file
 NEW_PROP_TAG(MPNCVtkCustomModule); //!< Vtk writer module for writing the user-specified quantities into the VTK output file
 
-NEW_PROP_TAG(VelocityAveragingInProblem);//!< Should the averaging of velocities be done in the problem?
+NEW_PROP_TAG(VelocityAveragingInModel);//!< Should the averaging of velocities be done in the model?
 
 //! specify which quantities are written to the vtk output files
 NEW_PROP_TAG(MPNCVtkAddPorosity);
diff --git a/dumux/boxmodels/MpNc/MpNcvtkwritercommon.hh b/dumux/boxmodels/MpNc/MpNcvtkwritercommon.hh
index 63f91de4470f61a2b8a8a3a78b6d71560cbf5166..a6b53eedae6fe34ea7ce93d8a18ba29f99ea79a8 100644
--- a/dumux/boxmodels/MpNc/MpNcvtkwritercommon.hh
+++ b/dumux/boxmodels/MpNc/MpNcvtkwritercommon.hh
@@ -67,7 +67,7 @@ class MPNCVtkWriterCommon : public MPNCVtkWriterModule<TypeTag>
     enum { numComponents = GET_PROP_VALUE(TypeTag, PTAG(NumComponents)) };
     enum { numEq = GET_PROP_VALUE(TypeTag, PTAG(NumEq)) };
 
-    enum { velocityAveragingInProblem = GET_PROP_VALUE(TypeTag, PTAG(VelocityAveragingInProblem)) };
+    enum { velocityAveragingInModel = GET_PROP_VALUE(TypeTag, PTAG(VelocityAveragingInModel)) };
 
     typedef Dune::FieldVector<Scalar, dim> VelocityVector;
     typedef Dune::BlockVector<VelocityVector> VelocityField;
diff --git a/dumux/boxmodels/MpNc/MpNcpropertydefaults.hh b/dumux/boxmodels/MpNc/MpNcpropertydefaults.hh
index f3e912a486f87eeba6f68ea8e9e164ebe9d50ad2..00dc2a55e4efb703729c08584c7b384b84743989 100644
--- a/dumux/boxmodels/MpNc/MpNcpropertydefaults.hh
+++ b/dumux/boxmodels/MpNc/MpNcpropertydefaults.hh
@@ -194,8 +194,8 @@ SET_PROP(BoxMPNC, MPNCVtkCustomModule)
 { typedef MPNCVtkWriterModule<TypeTag> type; };
 
 
-//!< Should the averaging of velocities be done in the problem? (By default in the output)
-SET_BOOL_PROP(BoxMPNC, VelocityAveragingInProblem, false);
+//!< Should the averaging of velocities be done in the Model? (By default in the output)
+SET_BOOL_PROP(BoxMPNC, VelocityAveragingInModel, false);
 
 //! Specify what to add to the VTK output by default
 SET_BOOL_PROP(BoxMPNC, MPNCVtkAddPorosity, true);